#ifndef NT2_INCLUDE_CONSTANTS_EPS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_EPS_HPP_INCLUDED

#include <nt2/constant/include/constants/eps.hpp>

#endif
